@@ -2,7 +2,7 @@
 
 from time import time
 
-from rrshare.rqUtil.rqSingleton import Singleton_wraps
+from .rqSingleton import Singleton_wraps
 
 @Singleton_wraps
 class rq_util_cache:
