@@ -4,8 +4,8 @@ from typing import List, Tuple, Union
 import tushare as ts
 import pandas as pd
 
-from rrshare.rqUtil import setting
-from rrshare.rqUtil.rqParameter import FREQUENCE, MARKET_TYPE
+from rrweb.rqUtil import setting
+from rrweb.rqUtil.rqParameter import FREQUENCE, MARKET_TYPE
     
 def rq_util_format_date2str(cursor_date):
     """
